Class: Google::Apis::GkehubV2alpha::ConfigManagementErrorResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

Model for a config file in the git repo with an associated Sync error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementErrorResource

Returns a new instance of ConfigManagementErrorResource.



706
707
708
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_gvkGoogle::Apis::GkehubV2alpha::ConfigManagementGroupVersionKind

A Kubernetes object's GVK. Corresponds to the JSON property resourceGvk



689
690
691
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 689

def resource_gvk
  @resource_gvk
end

#resource_nameString

Metadata name of the resource that is causing an error Corresponds to the JSON property resourceName

Returns:

  • (String)


694
695
696
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 694

def resource_name
  @resource_name
end

#resource_namespaceString

Namespace of the resource that is causing an error Corresponds to the JSON property resourceNamespace

Returns:

  • (String)


699
700
701
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 699

def resource_namespace
  @resource_namespace
end

#source_pathString

Path in the git repo of the erroneous config Corresponds to the JSON property sourcePath

Returns:

  • (String)


704
705
706
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 704

def source_path
  @source_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



711
712
713
714
715
716
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 711

def update!(**args)
  @resource_gvk = args[:resource_gvk] if args.key?(:resource_gvk)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_namespace = args[:resource_namespace] if args.key?(:resource_namespace)
  @source_path = args[:source_path] if args.key?(:source_path)
end