Class: Google::Apis::GkehubV2alpha::ConfigManagementGitConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::ConfigManagementGitConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Git repo configuration for a single cluster.
Instance Attribute Summary collapse
-
#gcp_service_account_email ⇒ String
Optional.
-
#https_proxy ⇒ String
Optional.
-
#policy_dir ⇒ String
Optional.
-
#secret_type ⇒ String
Required.
-
#sync_branch ⇒ String
Optional.
-
#sync_repo ⇒ String
Required.
-
#sync_rev ⇒ String
Optional.
-
#sync_wait_secs ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementGitConfig
constructor
A new instance of ConfigManagementGitConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementGitConfig
Returns a new instance of ConfigManagementGitConfig.
799 800 801 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcp_service_account_email ⇒ String
Optional. The Google Cloud Service Account Email used for auth when
secret_type is gcpServiceAccount.
Corresponds to the JSON property gcpServiceAccountEmail
758 759 760 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 758 def gcp_service_account_email @gcp_service_account_email end |
#https_proxy ⇒ String
Optional. URL for the HTTPS proxy to be used when communicating with the Git
repo.
Corresponds to the JSON property httpsProxy
764 765 766 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 764 def https_proxy @https_proxy end |
#policy_dir ⇒ String
Optional. The path within the Git repository that represents the top level of
the repo to sync. Default: the root directory of the repository.
Corresponds to the JSON property policyDir
770 771 772 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 770 def policy_dir @policy_dir end |
#secret_type ⇒ String
Required. Type of secret configured for access to the Git repo. Must be one of
ssh, cookiefile, gcenode, token, gcpserviceaccount, githubapp or none. The
validation of this is case-sensitive.
Corresponds to the JSON property secretType
777 778 779 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 777 def secret_type @secret_type end |
#sync_branch ⇒ String
Optional. The branch of the repository to sync from. Default: master.
Corresponds to the JSON property syncBranch
782 783 784 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 782 def sync_branch @sync_branch end |
#sync_repo ⇒ String
Required. The URL of the Git repository to use as the source of truth.
Corresponds to the JSON property syncRepo
787 788 789 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 787 def sync_repo @sync_repo end |
#sync_rev ⇒ String
Optional. Git revision (tag or hash) to check out. Default HEAD.
Corresponds to the JSON property syncRev
792 793 794 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 792 def sync_rev @sync_rev end |
#sync_wait_secs ⇒ Fixnum
Optional. Period in seconds between consecutive syncs. Default: 15.
Corresponds to the JSON property syncWaitSecs
797 798 799 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 797 def sync_wait_secs @sync_wait_secs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
804 805 806 807 808 809 810 811 812 813 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 804 def update!(**args) @gcp_service_account_email = args[:gcp_service_account_email] if args.key?(:gcp_service_account_email) @https_proxy = args[:https_proxy] if args.key?(:https_proxy) @policy_dir = args[:policy_dir] if args.key?(:policy_dir) @secret_type = args[:secret_type] if args.key?(:secret_type) @sync_branch = args[:sync_branch] if args.key?(:sync_branch) @sync_repo = args[:sync_repo] if args.key?(:sync_repo) @sync_rev = args[:sync_rev] if args.key?(:sync_rev) @sync_wait_secs = args[:sync_wait_secs] if args.key?(:sync_wait_secs) end |