Class: Google::Apis::GkehubV2alpha::ConfigManagementOciConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

OCI repo configuration for a single cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementOciConfig

Returns a new instance of ConfigManagementOciConfig.



1009
1010
1011
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcp_service_account_emailString

Optional. The Google Cloud Service Account Email used for auth when secret_type is gcpServiceAccount. Corresponds to the JSON property gcpServiceAccountEmail

Returns:

  • (String)


983
984
985
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 983

def 
  @gcp_service_account_email
end

#policy_dirString

Optional. The absolute path of the directory that contains the local resources. Default: the root directory of the image. Corresponds to the JSON property policyDir

Returns:

  • (String)


989
990
991
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 989

def policy_dir
  @policy_dir
end

#secret_typeString

Required. Type of secret configured for access to the OCI repo. Must be one of gcenode, gcpserviceaccount, k8sserviceaccount or none. The validation of this is case-sensitive. Corresponds to the JSON property secretType

Returns:

  • (String)


996
997
998
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 996

def secret_type
  @secret_type
end

#sync_repoString

Required. The OCI image repository URL for the package to sync from. e.g. LOCATION-docker.pkg.dev/PROJECT_ID/REPOSITORY_NAME/PACKAGE_NAME. Corresponds to the JSON property syncRepo

Returns:

  • (String)


1002
1003
1004
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1002

def sync_repo
  @sync_repo
end

#sync_wait_secsFixnum

Optional. Period in seconds between consecutive syncs. Default: 15. Corresponds to the JSON property syncWaitSecs

Returns:

  • (Fixnum)


1007
1008
1009
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1007

def sync_wait_secs
  @sync_wait_secs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1014
1015
1016
1017
1018
1019
1020
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1014

def update!(**args)
  @gcp_service_account_email = args[:gcp_service_account_email] if args.key?(:gcp_service_account_email)
  @policy_dir = args[:policy_dir] if args.key?(:policy_dir)
  @secret_type = args[:secret_type] if args.key?(:secret_type)
  @sync_repo = args[:sync_repo] if args.key?(:sync_repo)
  @sync_wait_secs = args[:sync_wait_secs] if args.key?(:sync_wait_secs)
end