Class: Google::Apis::GkehubV2alpha::ConfigManagementSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSpec

Returns a new instance of ConfigManagementSpec.



1276
1277
1278
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binauthzGoogle::Apis::GkehubV2alpha::ConfigManagementBinauthzConfig

Configuration for Binauthz. Corresponds to the JSON property binauthz



1239
1240
1241
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1239

def binauthz
  @binauthz
end

#clusterString

Optional. The user-specified cluster name used by Config Sync cluster-name- selector annotation or ClusterSelector, for applying configs to only a subset of clusters. Omit this field if the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Set this field if a name different from the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Corresponds to the JSON property cluster

Returns:

  • (String)


1249
1250
1251
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1249

def cluster
  @cluster
end

#config_syncGoogle::Apis::GkehubV2alpha::ConfigManagementConfigSync

Configuration for Config Sync Corresponds to the JSON property configSync



1254
1255
1256
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1254

def config_sync
  @config_sync
end

#hierarchy_controllerGoogle::Apis::GkehubV2alpha::ConfigManagementHierarchyControllerConfig

Configuration for Hierarchy Controller. Corresponds to the JSON property hierarchyController



1259
1260
1261
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1259

def hierarchy_controller
  @hierarchy_controller
end

#managementString

Optional. Enables automatic Feature management. Corresponds to the JSON property management

Returns:

  • (String)


1264
1265
1266
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1264

def management
  @management
end

#policy_controllerGoogle::Apis::GkehubV2alpha::ConfigManagementPolicyController

Configuration for Policy Controller Corresponds to the JSON property policyController



1269
1270
1271
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1269

def policy_controller
  @policy_controller
end

#versionString

Optional. Version of ACM installed. Corresponds to the JSON property version

Returns:

  • (String)


1274
1275
1276
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1274

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1281
1282
1283
1284
1285
1286
1287
1288
1289
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1281

def update!(**args)
  @binauthz = args[:binauthz] if args.key?(:binauthz)
  @cluster = args[:cluster] if args.key?(:cluster)
  @config_sync = args[:config_sync] if args.key?(:config_sync)
  @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller)
  @management = args[:management] if args.key?(:management)
  @policy_controller = args[:policy_controller] if args.key?(:policy_controller)
  @version = args[:version] if args.key?(:version)
end