Class: Google::Apis::GkehubV2alpha::ConfigManagementSyncError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

An ACM created error representing a problem syncing configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncError

Returns a new instance of ConfigManagementSyncError.



1375
1376
1377
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

An ACM defined error code Corresponds to the JSON property code

Returns:

  • (String)


1363
1364
1365
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1363

def code
  @code
end

#error_messageString

A description of the error Corresponds to the JSON property errorMessage

Returns:

  • (String)


1368
1369
1370
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1368

def error_message
  @error_message
end

#error_resourcesArray<Google::Apis::GkehubV2alpha::ConfigManagementErrorResource>

A list of config(s) associated with the error, if any Corresponds to the JSON property errorResources



1373
1374
1375
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1373

def error_resources
  @error_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
1383
1384
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1380

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @error_resources = args[:error_resources] if args.key?(:error_resources)
end