Class: Google::Apis::GkehubV2alpha::FeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

FeatureState contains high-level state information and per-feature state information for this MembershipFeature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeatureState

Returns a new instance of FeatureState.



1581
1582
1583
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appdevexperienceGoogle::Apis::GkehubV2alpha::AppDevExperienceState

State for App Dev Exp Feature. Corresponds to the JSON property appdevexperience



1535
1536
1537
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1535

def appdevexperience
  @appdevexperience
end

#clusterupgradeGoogle::Apis::GkehubV2alpha::ClusterUpgradeState

Per-membership state for this feature. Corresponds to the JSON property clusterupgrade



1540
1541
1542
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1540

def clusterupgrade
  @clusterupgrade
end

#configmanagementGoogle::Apis::GkehubV2alpha::ConfigManagementState

Anthos Config Management: State for a single cluster. Corresponds to the JSON property configmanagement



1545
1546
1547
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1545

def configmanagement
  @configmanagement
end

#identityserviceGoogle::Apis::GkehubV2alpha::IdentityServiceState

IdentityService: State for a single membership, analyzed and reported by feature controller. Corresponds to the JSON property identityservice



1551
1552
1553
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1551

def identityservice
  @identityservice
end

#meteringGoogle::Apis::GkehubV2alpha::MeteringState

Metering: State for a single membership, analyzed and reported by feature controller. Corresponds to the JSON property metering



1557
1558
1559
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1557

def metering
  @metering
end

#policycontrollerGoogle::Apis::GkehubV2alpha::PolicyControllerState

Policy Controller: State for a single cluster. Corresponds to the JSON property policycontroller



1562
1563
1564
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1562

def policycontroller
  @policycontroller
end

#rbacrolebindingactuationGoogle::Apis::GkehubV2alpha::RbacRoleBindingActuationState

RBAC RoleBinding Actuation: A membership-specific Feature state for the RBACRoleBindingActuation fleet feature. Corresponds to the JSON property rbacrolebindingactuation



1568
1569
1570
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1568

def rbacrolebindingactuation
  @rbacrolebindingactuation
end

#servicemeshGoogle::Apis::GkehubV2alpha::ServiceMeshState

Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller. Corresponds to the JSON property servicemesh



1574
1575
1576
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1574

def servicemesh
  @servicemesh
end

#stateGoogle::Apis::GkehubV2alpha::State

High-level state of a MembershipFeature. Corresponds to the JSON property state



1579
1580
1581
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1579

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1586

def update!(**args)
  @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience)
  @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade)
  @configmanagement = args[:configmanagement] if args.key?(:configmanagement)
  @identityservice = args[:identityservice] if args.key?(:identityservice)
  @metering = args[:metering] if args.key?(:metering)
  @policycontroller = args[:policycontroller] if args.key?(:policycontroller)
  @rbacrolebindingactuation = args[:rbacrolebindingactuation] if args.key?(:rbacrolebindingactuation)
  @servicemesh = args[:servicemesh] if args.key?(:servicemesh)
  @state = args[:state] if args.key?(:state)
end