Class: Google::Apis::GkehubV2alpha::IdentityServiceAzureAdConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::IdentityServiceAzureAdConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Configuration for the AzureAD Auth flow.
Instance Attribute Summary collapse
-
#client_id ⇒ String
ID for the registered client application that makes authentication requests to the Azure AD identity provider.
-
#client_secret ⇒ String
Input only.
-
#encrypted_client_secret ⇒ String
Output only.
-
#group_format ⇒ String
Optional.
-
#kubectl_redirect_uri ⇒ String
The redirect URL that kubectl uses for authorization.
-
#tenant ⇒ String
Kind of Azure AD account to be authenticated.
-
#user_claim ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceAzureAdConfig
constructor
A new instance of IdentityServiceAzureAdConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceAzureAdConfig
Returns a new instance of IdentityServiceAzureAdConfig.
1737 1738 1739 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_id ⇒ String
ID for the registered client application that makes authentication requests to
the Azure AD identity provider.
Corresponds to the JSON property clientId
1702 1703 1704 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1702 def client_id @client_id end |
#client_secret ⇒ String
Input only. Unencrypted AzureAD client secret will be passed to the GKE Hub
CLH.
Corresponds to the JSON property clientSecret
1708 1709 1710 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1708 def client_secret @client_secret end |
#encrypted_client_secret ⇒ String
Output only. Encrypted AzureAD client secret.
Corresponds to the JSON property encryptedClientSecret
NOTE: Values are automatically base64 encoded/decoded in the client library.
1714 1715 1716 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1714 def encrypted_client_secret @encrypted_client_secret end |
#group_format ⇒ String
Optional. Format of the AzureAD groups that the client wants for auth.
Corresponds to the JSON property groupFormat
1719 1720 1721 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1719 def group_format @group_format end |
#kubectl_redirect_uri ⇒ String
The redirect URL that kubectl uses for authorization.
Corresponds to the JSON property kubectlRedirectUri
1724 1725 1726 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1724 def kubectl_redirect_uri @kubectl_redirect_uri end |
#tenant ⇒ String
Kind of Azure AD account to be authenticated. Supported values are or for
accounts belonging to a specific tenant.
Corresponds to the JSON property tenant
1730 1731 1732 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1730 def tenant @tenant end |
#user_claim ⇒ String
Optional. Claim in the AzureAD ID Token that holds the user details.
Corresponds to the JSON property userClaim
1735 1736 1737 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1735 def user_claim @user_claim end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1742 1743 1744 1745 1746 1747 1748 1749 1750 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1742 def update!(**args) @client_id = args[:client_id] if args.key?(:client_id) @client_secret = args[:client_secret] if args.key?(:client_secret) @encrypted_client_secret = args[:encrypted_client_secret] if args.key?(:encrypted_client_secret) @group_format = args[:group_format] if args.key?(:group_format) @kubectl_redirect_uri = args[:kubectl_redirect_uri] if args.key?(:kubectl_redirect_uri) @tenant = args[:tenant] if args.key?(:tenant) @user_claim = args[:user_claim] if args.key?(:user_claim) end |