Class: Google::Apis::GkehubV2alpha::IdentityServiceLdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

Configuration for the LDAP Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceLdapConfig

Returns a new instance of IdentityServiceLdapConfig.



1890
1891
1892
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupGoogle::Apis::GkehubV2alpha::IdentityServiceGroupConfig

Contains the properties for locating and authenticating groups in the directory. Corresponds to the JSON property group



1871
1872
1873
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1871

def group
  @group
end

#serverGoogle::Apis::GkehubV2alpha::IdentityServiceServerConfig

Server settings for the external LDAP server. Corresponds to the JSON property server



1876
1877
1878
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1876

def server
  @server
end

#service_accountGoogle::Apis::GkehubV2alpha::IdentityServiceServiceAccountConfig

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate. Corresponds to the JSON property serviceAccount



1883
1884
1885
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1883

def 
  @service_account
end

#userGoogle::Apis::GkehubV2alpha::IdentityServiceUserConfig

Defines where users exist in the LDAP directory. Corresponds to the JSON property user



1888
1889
1890
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1888

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1895
1896
1897
1898
1899
1900
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1895

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @server = args[:server] if args.key?(:server)
  @service_account = args[:service_account] if args.key?(:service_account)
  @user = args[:user] if args.key?(:user)
end