Class: Google::Apis::GkehubV2alpha::IdentityServiceSamlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

Configuration for the SAML Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceSamlConfig

Returns a new instance of IdentityServiceSamlConfig.



2059
2060
2061
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_mappingHash<String,String>

Optional. The mapping of additional user attributes like nickname, birthday and address etc.. key is the name of this additional attribute. value is a string presenting as CEL(common expression language, go/cel) used for getting the value from the resources. Take nickname as an example, in this case, key is "attribute.nickname" and value is "assertion.nickname". Corresponds to the JSON property attributeMapping

Returns:

  • (Hash<String,String>)


2017
2018
2019
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2017

def attribute_mapping
  @attribute_mapping
end

#group_prefixString

Optional. Prefix to prepend to group name. Corresponds to the JSON property groupPrefix

Returns:

  • (String)


2022
2023
2024
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2022

def group_prefix
  @group_prefix
end

#groups_attributeString

Optional. The SAML attribute to read groups from. This value is expected to be a string and will be passed along as-is (with the option of being prefixed by the group_prefix). Corresponds to the JSON property groupsAttribute

Returns:

  • (String)


2029
2030
2031
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2029

def groups_attribute
  @groups_attribute
end

#identity_provider_certificatesArray<String>

Required. The list of IdP certificates to validate the SAML response against. Corresponds to the JSON property identityProviderCertificates

Returns:

  • (Array<String>)


2034
2035
2036
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2034

def identity_provider_certificates
  @identity_provider_certificates
end

#identity_provider_idString

Required. The entity ID of the SAML IdP. Corresponds to the JSON property identityProviderId

Returns:

  • (String)


2039
2040
2041
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2039

def identity_provider_id
  @identity_provider_id
end

#identity_provider_sso_uriString

Required. The URI where the SAML IdP exposes the SSO service. Corresponds to the JSON property identityProviderSsoUri

Returns:

  • (String)


2044
2045
2046
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2044

def identity_provider_sso_uri
  @identity_provider_sso_uri
end

#user_attributeString

Optional. The SAML attribute to read username from. If unspecified, the username will be read from the NameID element of the assertion in SAML response. This value is expected to be a string and will be passed along as-is (with the option of being prefixed by the user_prefix). Corresponds to the JSON property userAttribute

Returns:

  • (String)


2052
2053
2054
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2052

def user_attribute
  @user_attribute
end

#user_prefixString

Optional. Prefix to prepend to user name. Corresponds to the JSON property userPrefix

Returns:

  • (String)


2057
2058
2059
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2057

def user_prefix
  @user_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2064

def update!(**args)
  @attribute_mapping = args[:attribute_mapping] if args.key?(:attribute_mapping)
  @group_prefix = args[:group_prefix] if args.key?(:group_prefix)
  @groups_attribute = args[:groups_attribute] if args.key?(:groups_attribute)
  @identity_provider_certificates = args[:identity_provider_certificates] if args.key?(:identity_provider_certificates)
  @identity_provider_id = args[:identity_provider_id] if args.key?(:identity_provider_id)
  @identity_provider_sso_uri = args[:identity_provider_sso_uri] if args.key?(:identity_provider_sso_uri)
  @user_attribute = args[:user_attribute] if args.key?(:user_attribute)
  @user_prefix = args[:user_prefix] if args.key?(:user_prefix)
end