Class: Google::Apis::GkehubV2alpha::IdentityServiceServiceAccountConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::IdentityServiceServiceAccountConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate.
Instance Attribute Summary collapse
-
#simple_bind_credentials ⇒ Google::Apis::GkehubV2alpha::IdentityServiceSimpleBindCredentials
The structure holds the LDAP simple binding credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceServiceAccountConfig
constructor
A new instance of IdentityServiceServiceAccountConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceServiceAccountConfig
Returns a new instance of IdentityServiceServiceAccountConfig.
2125 2126 2127 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2125 def initialize(**args) update!(**args) end |
Instance Attribute Details
#simple_bind_credentials ⇒ Google::Apis::GkehubV2alpha::IdentityServiceSimpleBindCredentials
The structure holds the LDAP simple binding credential.
Corresponds to the JSON property simpleBindCredentials
2123 2124 2125 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2123 def simple_bind_credentials @simple_bind_credentials end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2130 2131 2132 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2130 def update!(**args) @simple_bind_credentials = args[:simple_bind_credentials] if args.key?(:simple_bind_credentials) end |