Class: Google::Apis::GkehubV2alpha::IdentityServiceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

IdentityService: State for a single membership, analyzed and reported by feature controller.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceState

Returns a new instance of IdentityServiceState.



2218
2219
2220
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failure_reasonString

The reason of the failure. Corresponds to the JSON property failureReason

Returns:

  • (String)


2200
2201
2202
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2200

def failure_reason
  @failure_reason
end

#installed_versionString

Installed AIS version. This is the AIS version installed on this member. The values makes sense iff state is OK. Corresponds to the JSON property installedVersion

Returns:

  • (String)


2206
2207
2208
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2206

def installed_version
  @installed_version
end

#member_configGoogle::Apis::GkehubV2alpha::IdentityServiceSpec

IdentityService: Configuration for a single membership. Corresponds to the JSON property memberConfig



2211
2212
2213
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2211

def member_config
  @member_config
end

#stateString

Deployment state on this member Corresponds to the JSON property state

Returns:

  • (String)


2216
2217
2218
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2216

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2223
2224
2225
2226
2227
2228
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2223

def update!(**args)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @installed_version = args[:installed_version] if args.key?(:installed_version)
  @member_config = args[:member_config] if args.key?(:member_config)
  @state = args[:state] if args.key?(:state)
end