Class: Google::Apis::GkehubV2alpha::ListMembershipFeaturesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

Response message for the GkeHubFeature.ListMembershipFeatures method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipFeaturesResponse

Returns a new instance of ListMembershipFeaturesResponse.



2348
2349
2350
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membership_featuresArray<Google::Apis::GkehubV2alpha::MembershipFeature>

The list of matching MembershipFeatures. Corresponds to the JSON property membershipFeatures



2334
2335
2336
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2334

def membership_features
  @membership_features
end

#next_page_tokenString

A token to request the next page of resources from the ListMembershipFeatures method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2341
2342
2343
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2341

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2346
2347
2348
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2346

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2353
2354
2355
2356
2357
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2353

def update!(**args)
  @membership_features = args[:membership_features] if args.key?(:membership_features)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end