Class: Google::Apis::GkehubV2alpha::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



2382
2383
2384
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2367
2368
2369
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2367

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::GkehubV2alpha::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



2372
2373
2374
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2372

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2380
2381
2382
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2380

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2387
2388
2389
2390
2391
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2387

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end