Class: Google::Apis::GkehubV2alpha::PolicyControllerPolicyContentState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

The state of the policy controller policy content

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerPolicyContentState

Returns a new instance of PolicyControllerPolicyContentState.



2877
2878
2879
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2877

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundle_statesHash<String,Google::Apis::GkehubV2alpha::PolicyControllerOnClusterState>

The state of the any bundles included in the chosen version of the manifest Corresponds to the JSON property bundleStates



2865
2866
2867
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2865

def bundle_states
  @bundle_states
end

#referential_sync_config_stateGoogle::Apis::GkehubV2alpha::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property referentialSyncConfigState



2870
2871
2872
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2870

def referential_sync_config_state
  @referential_sync_config_state
end

#template_library_stateGoogle::Apis::GkehubV2alpha::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property templateLibraryState



2875
2876
2877
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2875

def template_library_state
  @template_library_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2882
2883
2884
2885
2886
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2882

def update!(**args)
  @bundle_states = args[:bundle_states] if args.key?(:bundle_states)
  @referential_sync_config_state = args[:referential_sync_config_state] if args.key?(:referential_sync_config_state)
  @template_library_state = args[:template_library_state] if args.key?(:template_library_state)
end