Class: Google::Apis::GkehubV2alpha::ServiceMeshCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::ServiceMeshCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshCondition
constructor
A new instance of ServiceMeshCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshCondition
Returns a new instance of ServiceMeshCondition.
3275 3276 3277 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
3258 3259 3260 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3258 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
3263 3264 3265 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3263 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
3268 3269 3270 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3268 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
3273 3274 3275 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3273 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3280 3281 3282 3283 3284 3285 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3280 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |