Class: Google::Apis::GkehubV2alpha::ServiceMeshSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb

Overview

Service Mesh: Spec for a single Membership for the servicemesh feature

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshSpec

Returns a new instance of ServiceMeshSpec.



3371
3372
3373
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_apiString

Optional. Specifies the API that will be used for configuring the mesh workloads. Corresponds to the JSON property configApi

Returns:

  • (String)


3352
3353
3354
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3352

def config_api
  @config_api
end

#control_planeString

Deprecated: use management instead Enables automatic control plane management. Corresponds to the JSON property controlPlane

Returns:

  • (String)


3358
3359
3360
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3358

def control_plane
  @control_plane
end

#default_channelString

Determines which release channel to use for default injection and service mesh APIs. Corresponds to the JSON property defaultChannel

Returns:

  • (String)


3364
3365
3366
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3364

def default_channel
  @default_channel
end

#managementString

Optional. Enables automatic Service Mesh management. Corresponds to the JSON property management

Returns:

  • (String)


3369
3370
3371
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3369

def management
  @management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3376
3377
3378
3379
3380
3381
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 3376

def update!(**args)
  @config_api = args[:config_api] if args.key?(:config_api)
  @control_plane = args[:control_plane] if args.key?(:control_plane)
  @default_channel = args[:default_channel] if args.key?(:default_channel)
  @management = args[:management] if args.key?(:management)
end