Class: Google::Apis::GkehubV2alpha::ConfigManagementDeploymentOverride
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::ConfigManagementDeploymentOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Configuration for a deployment override.
Instance Attribute Summary collapse
-
#containers ⇒ Array<Google::Apis::GkehubV2alpha::ConfigManagementContainerOverride>
Optional.
-
#deployment_name ⇒ String
Required.
-
#deployment_namespace ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
constructor
A new instance of ConfigManagementDeploymentOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementDeploymentOverride
Returns a new instance of ConfigManagementDeploymentOverride.
670 671 672 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containers ⇒ Array<Google::Apis::GkehubV2alpha::ConfigManagementContainerOverride>
Optional. The containers of the deployment resource to be overridden.
Corresponds to the JSON property containers
658 659 660 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 658 def containers @containers end |
#deployment_name ⇒ String
Required. The name of the deployment resource to be overridden.
Corresponds to the JSON property deploymentName
663 664 665 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 663 def deployment_name @deployment_name end |
#deployment_namespace ⇒ String
Required. The namespace of the deployment resource to be overridden.
Corresponds to the JSON property deploymentNamespace
668 669 670 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 668 def deployment_namespace @deployment_namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
675 676 677 678 679 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 675 def update!(**args) @containers = args[:containers] if args.key?(:containers) @deployment_name = args[:deployment_name] if args.key?(:deployment_name) @deployment_namespace = args[:deployment_namespace] if args.key?(:deployment_namespace) end |