Class: Google::Apis::GkehubV2alpha::GKEHubService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::GkehubV2alpha::GKEHubService
- Defined in:
- lib/google/apis/gkehub_v2alpha/service.rb
Overview
GKE Hub API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://gkehub.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_membership_feature(parent, membership_feature_object = nil, feature_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Creates membershipFeature under a given parent.
-
#delete_project_location_membership_feature(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Removes a membershipFeature.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Location
Gets information about a location.
-
#get_project_location_membership_feature(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::MembershipFeature
========= MembershipFeature Services ========= Gets details of a membershipFeature.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ GKEHubService
constructor
A new instance of GKEHubService.
-
#list_project_location_membership_features(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::ListMembershipFeaturesResponse
Lists MembershipFeatures in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_membership_feature(name, membership_feature_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Updates an existing MembershipFeature.
Constructor Details
#initialize ⇒ GKEHubService
Returns a new instance of GKEHubService.
47 48 49 50 51 52 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-gkehub_v2alpha', client_version: Google::Apis::GkehubV2alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 363 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha/{+name}:cancel', ) command.request_representation = Google::Apis::GkehubV2alpha::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::GkehubV2alpha::Empty::Representation command.response_class = Google::Apis::GkehubV2alpha::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_membership_feature(parent, membership_feature_object = nil, feature_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Creates membershipFeature under a given parent.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 157 def create_project_location_membership_feature(parent, membership_feature_object = nil, feature_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2alpha/{+parent}/features', ) command.request_representation = Google::Apis::GkehubV2alpha::MembershipFeature::Representation command.request_object = membership_feature_object command.response_representation = Google::Apis::GkehubV2alpha::Operation::Representation command.response_class = Google::Apis::GkehubV2alpha::Operation command.params['parent'] = parent unless parent.nil? command.query['featureId'] = feature_id unless feature_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_membership_feature(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Removes a membershipFeature.
194 195 196 197 198 199 200 201 202 203 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 194 def delete_project_location_membership_feature(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2alpha/{+name}', ) command.response_representation = Google::Apis::GkehubV2alpha::Operation::Representation command.response_class = Google::Apis::GkehubV2alpha::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha/{+name}', ) command.response_representation = Google::Apis::GkehubV2alpha::Location::Representation command.response_class = Google::Apis::GkehubV2alpha::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_membership_feature(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::MembershipFeature
========= MembershipFeature Services ========= Gets details of a membershipFeature.
227 228 229 230 231 232 233 234 235 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 227 def get_project_location_membership_feature(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha/{+name}', ) command.response_representation = Google::Apis::GkehubV2alpha::MembershipFeature::Representation command.response_class = Google::Apis::GkehubV2alpha::MembershipFeature command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
396 397 398 399 400 401 402 403 404 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 396 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha/{+name}', ) command.response_representation = Google::Apis::GkehubV2alpha::Operation::Representation command.response_class = Google::Apis::GkehubV2alpha::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_membership_features(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::ListMembershipFeaturesResponse
Lists MembershipFeatures in a given project and location.
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 275 def list_project_location_membership_features(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha/{+parent}/features', ) command.response_representation = Google::Apis::GkehubV2alpha::ListMembershipFeaturesResponse::Representation command.response_class = Google::Apis::GkehubV2alpha::ListMembershipFeaturesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
441 442 443 444 445 446 447 448 449 450 451 452 453 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 441 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha/{+name}/operations', ) command.response_representation = Google::Apis::GkehubV2alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::GkehubV2alpha::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::ListLocationsResponse
Lists information about the supported locations for this service.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 117 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2alpha/{+name}/locations', ) command.response_representation = Google::Apis::GkehubV2alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::GkehubV2alpha::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_membership_feature(name, membership_feature_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::GkehubV2alpha::Operation
Updates an existing MembershipFeature.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/google/apis/gkehub_v2alpha/service.rb', line 320 def patch_project_location_membership_feature(name, membership_feature_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2alpha/{+name}', ) command.request_representation = Google::Apis::GkehubV2alpha::MembershipFeature::Representation command.request_object = membership_feature_object command.response_representation = Google::Apis::GkehubV2alpha::Operation::Representation command.response_class = Google::Apis::GkehubV2alpha::Operation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |