Class: Google::Apis::GkehubV2alpha::IdentityServiceDiagnosticInterface
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::IdentityServiceDiagnosticInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Configuration options for the AIS diagnostic interface.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Determines whether to enable the diagnostic interface.
-
#expiration_time ⇒ String
Determines the expiration time of the diagnostic interface enablement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceDiagnosticInterface
constructor
A new instance of IdentityServiceDiagnosticInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceDiagnosticInterface
Returns a new instance of IdentityServiceDiagnosticInterface.
1769 1770 1771 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Determines whether to enable the diagnostic interface.
Corresponds to the JSON property enabled
1760 1761 1762 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1760 def enabled @enabled end |
#expiration_time ⇒ String
Determines the expiration time of the diagnostic interface enablement. When
reached, requests to the interface would be automatically rejected.
Corresponds to the JSON property expirationTime
1767 1768 1769 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1767 def expiration_time @expiration_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1774 1775 1776 1777 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1774 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) end |