Class: Google::Apis::GkehubV2alpha::IdentityServiceGroupConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::IdentityServiceGroupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Contains the properties for locating and authenticating groups in the directory.
Instance Attribute Summary collapse
-
#base_dn ⇒ String
Required.
-
#filter ⇒ String
Optional.
-
#id_attribute ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceGroupConfig
constructor
A new instance of IdentityServiceGroupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceGroupConfig
Returns a new instance of IdentityServiceGroupConfig.
1826 1827 1828 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1826 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_dn ⇒ String
Required. The location of the subtree in the LDAP directory to search for
group entries.
Corresponds to the JSON property baseDn
1809 1810 1811 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1809 def base_dn @base_dn end |
#filter ⇒ String
Optional. Optional filter to be used when searching for groups a user belongs
to. This can be used to explicitly match only certain groups in order to
reduce the amount of groups returned for each user. This defaults to "(
objectClass=Group)".
Corresponds to the JSON property filter
1817 1818 1819 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1817 def filter @filter end |
#id_attribute ⇒ String
Optional. The identifying name of each group a user belongs to. For example,
if this is set to "distinguishedName" then RBACs and other group expectations
should be written as full DNs. This defaults to "distinguishedName".
Corresponds to the JSON property idAttribute
1824 1825 1826 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1824 def id_attribute @id_attribute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1831 1832 1833 1834 1835 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 1831 def update!(**args) @base_dn = args[:base_dn] if args.key?(:base_dn) @filter = args[:filter] if args.key?(:filter) @id_attribute = args[:id_attribute] if args.key?(:id_attribute) end |