Class: Google::Apis::GkehubV2alpha::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV2alpha::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v2alpha/classes.rb,
lib/google/apis/gkehub_v2alpha/representations.rb,
lib/google/apis/gkehub_v2alpha/representations.rb
Overview
Metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#cancel_requested ⇒ Boolean
(also: #cancel_requested?)
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#status_detail ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
2642 2643 2644 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
2606 2607 2608 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2606 def api_version @api_version end |
#cancel_requested ⇒ Boolean Also known as: cancel_requested?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property cancelRequested
2614 2615 2616 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2614 def cancel_requested @cancel_requested end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
2620 2621 2622 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2620 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
2625 2626 2627 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2625 def end_time @end_time end |
#status_detail ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusDetail
2630 2631 2632 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2630 def status_detail @status_detail end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
2635 2636 2637 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2635 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
2640 2641 2642 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2640 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2647 2648 2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/google/apis/gkehub_v2alpha/classes.rb', line 2647 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @status_detail = args[:status_detail] if args.key?(:status_detail) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |